==> cv-react-library-0.1.16.tgz: package/src/components/native/DateTimePicker/DateTimePicker.js <==
import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { View, TouchableOpacity } from 'react-native';
import NativeDateTimePicker from 'react-native-modal-datetime-picker';
import { format } from 'date-fns';
import TextLabel from '../TextLabel/TextLabel';

// Styles
import getStyles from './DateTimePicker.styles';

/**
 * A control for selecting a date, time or both.
 */
class DateTimePicker extends Component {
    static propTypes = {
        /** Styles for this component */
        contextStyles: PropTypes.shape({
            /** Styles for the touchable picker container */
            container: PropTypes.object,

            /** Styles for the icon */
            icon: PropTypes.object,

            /** Styles for the iOS picker cancel text */
            pickerCancelText: PropTypes.object,

            /** Styles for the iOS picker confirm text */
            pickerConfirmText: PropTypes.object,

            /** Styles for the iOS picker container */
            pickerContainer: PropTypes.object,

            /** Styles for the iOS picker title text */
            pickerTitleText: PropTypes.object,

            /** Styles for the input text */
            text: PropTypes.object,
        }),

        /** Prevent press events from showing the menu */
        disabled: PropTypes.bool,

        /** Custom display format (see NPM package date-fns) */
        displayFormat: PropTypes.string,

        /** Display the date picker in a 24 hour format */
        is24Hour: PropTypes.bool,

        /** Date type format: date, time, datetime */
        mode: PropTypes.oneOf([
            'date',
            'time',
            'datetime',
        ]),

        /** Called when cancel was selected */
        onCancel: PropTypes.func,

        /**
         * Called when the picker date has changed
         * @param {Date} date - The selected date
         */
        onChange: PropTypes.func,

        /**
         * Called when picker date selection has been confirmed
         * @param {Date} date - The selected date
         */
        onConfirm: PropTypes.func,

        /** Picker date value */
        pickerDate: PropTypes.instanceOf(Date),

        /** Selected date value */
        selectedDate: PropTypes.instanceOf(Date),

        /** Id used for testing */
        testID: PropTypes.string,

        /** Indicator the menu is visible */
        visible: PropTypes.bool,
    };

    static defaultProps = {
        contextStyles: {},
        displayFormat: 'M/d/yy, h:mm A',
        mode: 'date',
    };

    constructor(props) {
        super(props);
        const {
            selectedDate,
            pickerDate,
            visible,
        } = props;
        this.state = {
            selectedDate: selectedDate instanceof Date && selectedDate.getDate() ? selectedDate : null,
            pickerDate: pickerDate || new Date(),
            visible,
        };
    }

    render() {
        const {
            contextStyles,
            disabled,
            displayFormat,
            is24Hour,
            mode,
            onChange,
            testID,
        } = this.props;
        const {
            selectedDate,
            pickerDate,
            visible,
        } = this.state;

        const styles = getStyles(contextStyles);

        // Generate touchable props
        const touchableProps = {
            activeOpacity: 0.5,
        };
        if (!disabled) { touchableProps.onPress = this.show; }
        if (testID) { touchableProps.testID = `${testID}__touchable`; }

        // Generate container props
        const containerProps = {
            style: styles.container,
        };
        if (disabled) { containerProps.style = styles.disabledContainer; }
        if (testID) { containerProps.testID = `${testID}__container`; }

        // Generate text props
        const textProps = {
            contextStyles: {
                text: styles.text,
            },
        };
        let dateText = '';
        if (selectedDate instanceof Date && selectedDate.getDate()) {
            // Default to date & time
            let dateTimeFormat = displayFormat;

            // Date only
            if (mode === 'date') {
                dateTimeFormat = 'M/d/yy';
            }

            // Time only
            else if (mode === 'time') {
                dateTimeFormat = 'h:mm A';
            }

            dateText = format(selectedDate, dateTimeFormat);
        }
        if (testID) { textProps.testID = `${testID}__text`; }

        // Generate icon props
        const iconProps = {
            contextStyles: {
                text: styles.icon,
            },
        };
        if (testID) { iconProps.testID = `${testID}__icon`; }

        // Generate picker props
        const pickerProps = {
            cancelTextIOS: 'Cancel',
            confirmTextIOS: 'Confirm',
            titleIOS: 'Pick a date and time',
            titleStyle: {
                ...styles.pickerTitleText,
            },
            confirmTextStyle: {
                ...styles.pickerConfirmText,
            },
            cancelTextStyle: {
                ...styles.pickerCancelText,
            },
            datePickerContainerStyleIOS: {
                ...styles.pickerContainer,
            },
            date: pickerDate,
            mode,
            is24Hour,
            isVisible: true,
            onCancel: this.handleCancel,
            onChange: onChange,
            onConfirm: this.handleConfirm,
        };
        if (testID) { pickerProps.testID = `${testID}__picker`; }
        if (mode === 'date') {
            pickerProps.titleIOS = 'Pick a date';
        }
        else if (mode === 'time') {
            pickerProps.titleIOS = 'Pick a time';
        }

        return (
            <Fragment>
                <TouchableOpacity { ...touchableProps }>
                    <View { ...containerProps }>
                        <TextLabel { ...textProps }>
                            { dateText }
                        </TextLabel>
                        <TextLabel { ...iconProps }>&#9998;</TextLabel>
                    </View>
                </TouchableOpacity>
                { visible && <NativeDateTimePicker { ...pickerProps } /> }
            </Fragment>
        );
    }

    componentDidUpdate(prevProps) {
        const {
            selectedDate: oldSelectedDate,
            pickerDate: oldPickerDate,
            visible: wasVisible,
        } = prevProps;
        const {
            selectedDate,
            pickerDate,
            visible: isVisible,
        } = this.props;
        const newState = {};
        if (oldSelectedDate !== selectedDate) {
            newState.selectedDate = selectedDate;
        }
        if (oldPickerDate !== pickerDate) {
            newState.pickerDate = pickerDate;
        }
        if (wasVisible !== isVisible) {
            newState.visible = isVisible;
        }
        if (Object.keys(newState).length) {
            this.reset(newState);
        }
    }

    handleCancel = () => {
        const { onCancel } = this.props;
        this.setState({ visible: false }, () => {
            if (onCancel) {
                onCancel();
            }
        });
    };

    handleConfirm = (date) => {
        const { pickerDate } = this.state;
        const { onConfirm } = this.props;
        const selectedDate = date && date.getDate() ? date : pickerDate;
        this.setState({
            selectedDate,
            visible: false,
        }, () => {
            if (onConfirm) {
                onConfirm(selectedDate);
            }
        });
    };

    show = () => {
        const { selectedDate } = this.state;
        this.setState({
            // Set the picker date to the selected date if one exists
            // else use the current date
            pickerDate: selectedDate instanceof Date && selectedDate.getDate() ? selectedDate : new Date(),
            visible: true,
        });
    };

    reset(newState) {
        this.setState(newState);
    }
}

export default DateTimePicker;

==> cv-react-library-0.1.29.tgz: package/src/components/native/DateTimePicker/DateTimePicker.js <==
import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { View, TouchableOpacity } from 'react-native';
import NativeDateTimePicker from 'react-native-modal-datetime-picker';
import { format } from 'date-fns';
import TextLabel from '../TextLabel/TextLabel';

// Styles
import getStyles from './DateTimePicker.styles';

/**
 * A control for selecting a date, time or both.
 */
class DateTimePicker extends Component {
    static propTypes = {
        /** Styles for this component */
        contextStyles: PropTypes.shape({
            /** Styles for the touchable picker container */
            container: PropTypes.object,

            /** Styles for the icon */
            icon: PropTypes.object,

            /** Styles for the iOS picker cancel text */
            pickerCancelText: PropTypes.object,

            /** Styles for the iOS picker confirm text */
            pickerConfirmText: PropTypes.object,

            /** Styles for the iOS picker container */
            pickerContainer: PropTypes.object,

            /** Styles for the iOS picker title text */
            pickerTitleText: PropTypes.object,

            /** Styles for the input text */
            text: PropTypes.object,
        }),

        /** Prevent press events from showing the menu */
        disabled: PropTypes.bool,

        /** Custom display format (see NPM package date-fns) */
        displayFormat: PropTypes.string,

        /** Display the date picker in a 24 hour format */
        is24Hour: PropTypes.bool,

        /** Date type format: date, time, datetime */
        mode: PropTypes.oneOf([
            'date',
            'time',
            'datetime',
        ]),

        /** Called when cancel was selected */
        onCancel: PropTypes.func,

        /**
         * Called when the picker date has changed
         * @param {Date} date - The selected date
         */
        onChange: PropTypes.func,

        /**
         * Called when picker date selection has been confirmed
         * @param {Date} date - The selected date
         */
        onConfirm: PropTypes.func,

        /** Picker date value */
        pickerDate: PropTypes.instanceOf(Date),

        /** Selected date value */
        selectedDate: PropTypes.instanceOf(Date),

        /** Id used for testing */
        testID: PropTypes.string,

        /** Indicator the menu is visible */
        visible: PropTypes.bool,
    };

    static defaultProps = {
        contextStyles: {},
        displayFormat: 'M/d/yy, h:mm A',
        mode: 'date',
    };

    constructor(props) {
        super(props);
        const {
            selectedDate,
            pickerDate,
            visible,
        } = props;
        this.state = {
            selectedDate: selectedDate instanceof Date && selectedDate.getDate() ? selectedDate : null,
            pickerDate: pickerDate || new Date(),
            visible,
        };
    }

    render() {
        const {
            contextStyles,
            disabled,
            displayFormat,
            is24Hour,
            mode,
            onChange,
            testID,
        } = this.props;
        const {
            selectedDate,
            pickerDate,
            visible,
        } = this.state;

        const styles = getStyles(contextStyles);

        // Generate container props
        const containerProps = {
            activeOpacity: 0.5,
            style: styles.container,
        };
        if (!disabled) { containerProps.onPress = this.show; }
        if (disabled) { containerProps.style = styles.disabledContainer; }
        if (testID) { containerProps.testID = `${testID}__container`; }

        // Generate text props
        const textProps = {
            contextStyles: {
                text: styles.text,
            },
        };
        let dateText = '';
        if (selectedDate instanceof Date && selectedDate.getDate()) {
            // Default to date & time
            let dateTimeFormat = displayFormat;

            // Date only
            if (mode === 'date') {
                dateTimeFormat = 'M/d/yy';
            }

            // Time only
            else if (mode === 'time') {
                dateTimeFormat = 'h:mm A';
            }

            dateText = format(selectedDate, dateTimeFormat);
        }
        if (testID) { textProps.testID = `${testID}__text`; }

        // Generate icon props
        const iconProps = {
            contextStyles: {
                text: styles.icon,
            },
        };
        if (testID) { iconProps.testID = `${testID}__icon`; }

        // Generate picker props
        const pickerProps = {
            cancelTextIOS: 'Cancel',
            confirmTextIOS: 'Confirm',
            titleIOS: 'Pick a date and time',
            titleStyle: {
                ...styles.pickerTitleText,
            },
            confirmTextStyle: {
                ...styles.pickerConfirmText,
            },
            cancelTextStyle: {
                ...styles.pickerCancelText,
            },
            datePickerContainerStyleIOS: {
                ...styles.pickerContainer,
            },
            date: pickerDate,
            mode,
            is24Hour,
            isVisible: true,
            onCancel: this.handleCancel,
            onChange: onChange,
            onConfirm: this.handleConfirm,
        };
        if (testID) { pickerProps.testID = `${testID}__picker`; }
        if (mode === 'date') {
            pickerProps.titleIOS = 'Pick a date';
        }
        else if (mode === 'time') {
            pickerProps.titleIOS = 'Pick a time';
        }

        return (
            <Fragment>
                <TouchableOpacity { ...containerProps }>
                    <TextLabel { ...textProps }>
                        { dateText }
                    </TextLabel>
                    <TextLabel { ...iconProps }>&#9998;</TextLabel>
                </TouchableOpacity>
                { visible && <NativeDateTimePicker { ...pickerProps } /> }
            </Fragment>
        );
    }

    componentDidUpdate(prevProps) {
        const {
            selectedDate: oldSelectedDate,
            pickerDate: oldPickerDate,
            visible: wasVisible,
        } = prevProps;
        const {
            selectedDate,
            pickerDate,
            visible: isVisible,
        } = this.props;
        const newState = {};
        if (oldSelectedDate !== selectedDate) {
            newState.selectedDate = selectedDate;
        }
        if (oldPickerDate !== pickerDate) {
            newState.pickerDate = pickerDate;
        }
        if (wasVisible !== isVisible) {
            newState.visible = isVisible;
        }
        if (Object.keys(newState).length) {
            this.reset(newState);
        }
    }

    handleCancel = () => {
        const { onCancel } = this.props;
        this.setState({ visible: false }, () => {
            if (onCancel) {
                onCancel();
            }
        });
    };

    handleConfirm = (date) => {
        const { pickerDate } = this.state;
        const { onConfirm } = this.props;
        const selectedDate = date && date.getDate() ? date : pickerDate;
        this.setState({
            selectedDate,
            visible: false,
        }, () => {
            if (onConfirm) {
                onConfirm(selectedDate);
            }
        });
    };

    show = () => {
        const { selectedDate } = this.state;
        this.setState({
            // Set the picker date to the selected date if one exists
            // else use the current date
            pickerDate: selectedDate instanceof Date && selectedDate.getDate() ? selectedDate : new Date(),
            visible: true,
        });
    };

    reset(newState) {
        this.setState(newState);
    }
}

export default DateTimePicker;
